==> 3.5.12-core.tar: kdemultimedia/arts/gui/kde/kframe_impl.cpp <==
/*
    Copyright (C) 2002 Matthias Kretz <kretz@kde.org>

    This library is free software; you can redistribute it and/or
    modify it under the terms of the GNU Library General Public
    License version 2 as published by the Free Software Foundation.

    This library is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
    Library General Public License for more details.

    You should have received a copy of the GNU Library General Public License
    along with this library; see the file COPYING.LIB.  If not, write to
    the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
    Boston, MA 02110-1301, USA.

*/
// $Id: kframe_impl.cpp 1157644 2010-07-31 19:43:15Z tpearson $

#include "kframe_impl.h"
#include <tqframe.h>
#include <debug.h>
#include <stdio.h>

using namespace Arts;
using namespace std;

KFrame_impl::KFrame_impl( TQFrame * widget )
	: KWidget_impl( widget ? widget : new TQFrame )
{
	_qframe = static_cast<TQFrame*>( _qwidget );
	assert( _qframe );
}

long KFrame_impl::margin()
{
	return _qframe->margin();
}

void KFrame_impl::margin( long m )
{
	_qframe->setMargin( m );
}

long KFrame_impl::linewidth()
{
	return _qframe->lineWidth();
}

void KFrame_impl::linewidth( long lw )
{
	_qframe->setLineWidth( lw );
}

long KFrame_impl::midlinewidth()
{
	return _qframe->midLineWidth();
}

void KFrame_impl::midlinewidth( long mlw )
{
	_qframe->setMidLineWidth( mlw );
}

long KFrame_impl::framestyle()
{
	return _qframe->frameStyle();
}

void KFrame_impl::framestyle( long fs )
{
	_qframe->setFrameStyle( fs );
}

Shape KFrame_impl::frameshape()
{
	return ( Shape )_qframe->frameShape();
}

void KFrame_impl::frameshape( Shape fs )
{
	_qframe->setFrameShape( ( TQFrame::Shape )fs );
}

Shadow KFrame_impl::frameshadow()
{
	return ( Shadow )_qframe->frameShadow();
}

void KFrame_impl::frameshadow( Shadow fs )
{
	_qframe->setFrameShadow( ( TQFrame::Shadow )fs );
}

REGISTER_IMPLEMENTATION(KFrame_impl);

// vim: sw=4 ts=4

==> 3.5.13-core.tar: kdemultimedia/arts/gui/kde/kframe_impl.cpp <==
/*
    Copyright (C) 2002 Matthias Kretz <kretz@kde.org>

    This library is free software; you can redistribute it and/or
    modify it under the terms of the GNU Library General Public
    License version 2 as published by the Free Software Foundation.

    This library is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
    Library General Public License for more details.

    You should have received a copy of the GNU Library General Public License
    along with this library; see the file COPYING.LIB.  If not, write to
    the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
    Boston, MA 02110-1301, USA.

*/
// $Id: kframe_impl.cpp 1236079 2011-06-11 06:00:15Z tpearson $

#include "kframe_impl.h"
#include <tqframe.h>
#include <debug.h>
#include <stdio.h>

using namespace Arts;
using namespace std;

KFrame_impl::KFrame_impl( TQFrame * widget )
	: KWidget_impl( widget ? widget : new TQFrame )
{
	_qframe = static_cast<TQFrame*>( _qwidget );
	assert( _qframe );
}

long KFrame_impl::margin()
{
	return _qframe->margin();
}

void KFrame_impl::margin( long m )
{
	_qframe->setMargin( m );
}

long KFrame_impl::linewidth()
{
	return _qframe->lineWidth();
}

void KFrame_impl::linewidth( long lw )
{
	_qframe->setLineWidth( lw );
}

long KFrame_impl::midlinewidth()
{
	return _qframe->midLineWidth();
}

void KFrame_impl::midlinewidth( long mlw )
{
	_qframe->setMidLineWidth( mlw );
}

long KFrame_impl::framestyle()
{
	return _qframe->frameStyle();
}

void KFrame_impl::framestyle( long fs )
{
	_qframe->setFrameStyle( fs );
}

Shape KFrame_impl::frametqshape()
{
	return ( Shape )_qframe->frameShape();
}

void KFrame_impl::frametqshape( Shape fs )
{
	_qframe->setFrameShape( ( TQFrame::Shape )fs );
}

Shadow KFrame_impl::frameshadow()
{
	return ( Shadow )_qframe->frameShadow();
}

void KFrame_impl::frameshadow( Shadow fs )
{
	_qframe->setFrameShadow( ( TQFrame::Shadow )fs );
}

REGISTER_IMPLEMENTATION(KFrame_impl);

// vim: sw=4 ts=4
